package Task::Mechanistic;

use 5.005;
use strict;
use warnings;

our $VERSION = '0.02';

1;
__END__


=head1 NAME

Task::Mechanistic - Perl extension to install WWW::Mechanize

=head1 SYNOPSIS

  cpan Task::Mechanistic

=head1 DESCRIPTION

Installs WWW::Mechanize and its dependencies

=head2 EXPORT

  None by default.

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2013 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.005, or at your option, any later version of Perl 5 you may have available.

=cut
